@@ -4,6 +4,10 @@
 #' on subject level parameters of a ctStanFit object.
 #'
 #' @param fit fit object from \code{\link{ctStanFit}}
+#' @param returndifference logical. If FALSE, absolute parameter values are returned. 
+#' If TRUE, only the effect of the covariate (i.e. without the average value of the parameter)
+#' are returned. The former can be easier to interpret, but the latter are more likely to fit on 
+#' a single plot.
 #' @param probs numeric vector of quantile probabilities from 0 to 1. Specify 3
 #' values if plotting, the 2nd will be drawn as a line with uncertainty polygon
 #' based on 1st and 3rd.
@@ -28,8 +32,7 @@
 #'
 #' @examples
 #' ctStanTIpredeffects(ctstantestfit,plot=TRUE)
-#' ctStanTIpredeffects(ctstantestfit,plot=TRUE,separate=TRUE)
-ctStanTIpredeffects<-function(fit,probs=c(.25,.5,.75),
+ctStanTIpredeffects<-function(fit,returndifference=FALSE, probs=c(.025,.5,.975),
   whichTIpreds=1,whichpars='all',
   plot=FALSE,...){
   
@@ -71,9 +74,9 @@ noeffect<-aaply(1:npars, 1,function(pari){ #for each param
   return(out)
 })
 
-deffect<-effect-array(noeffect,dim=dim(effect))
+if(returndifference) effect<-effect-array(noeffect,dim=dim(effect))
 
-out<-aaply(probs,1,function(x) ctCollapse(deffect,2,quantile,probs=x))
+out<-aaply(probs,1,function(x) ctCollapse(effect,2,quantile,probs=x))
 dimnames(out)=list(Quantile=paste0('Quantile',probs),
   popmean=spec$param,
   subject=tiorder #subjects reordered because tipreds were at top
@@ -83,7 +86,7 @@ out <- aperm(out, c(3,2,1))
 
 if(!plot) return(out) else {
   ctPlotArray(yarray=out,x=tipreds[,1],
-  plotcontrol=list(ylab='Effect',xlab=colnames(tipreds)[1]))
+  plotcontrol=list(ylab='Effect',xlab=colnames(tipreds)[1]),...)
 }
 }
 
@@ -98,14 +101,10 @@ if(!plot) return(out) else {
 #' @param yarray 3 dimensional array to use for Y values
 #' @param x numeric vector specifying x axis
 #' @param grid Logical. Plot with a grid?
-#' @param separate Logical. Generate a plot per variable (2nd margin of array)
-#' or plot all on one?
 #' @param colvec color vector of same length as 2nd margin.
 #' @param lwdvec lwd vector of same length as 2nd margin.
 #' @param ltyvec lty vector of same length as 2nd margin.
 #' @param typevec type vector of same length as 2nd margin.
-#' @param mainvec main vector of same length as 2nd margin, only used if 
-#' separate=TRUE.
 #' @param plotcontrol list of arguments to pass to plot.
 #' @param legend Logical. Draw a legend?
 #' @param legendcontrol list of arguments to pass to \code{\link[graphics]{legend}}.
@@ -120,15 +119,15 @@ if(!plot) return(out) else {
 #' @examples
 #' y <- ctStanTIpredeffects(ctstantestfit,plot=FALSE)
 #' x<-ctstantestfit$data$tipreds[order(ctstantestfit$data$tipreds[,1]),1]
-#' ctPlotArray(y,x,separate=TRUE)
+#' ctPlotArray(y,x)
 ctPlotArray <- function(yarray,x,
-grid=TRUE,separate=FALSE,
+grid=TRUE,
   colvec='auto',lwdvec='auto',ltyvec='auto',typevec='auto',
-  mainvec='auto',
-  plotcontrol=list(ylab='Array values', xlab='X values'),
+  plotcontrol=list(ylab='Array values', xlab='X values',xaxs='i'),
 legend=TRUE,legendcontrol=list(x='topright'),
-polygon=TRUE, polygonalpha=.1,polygoncontrol=list(border=NA)){
+polygon=TRUE, polygonalpha=.1,polygoncontrol=list(border=NA,steps=50)){
 
+  separate=FALSE
   nvars<-dim(yarray)[2]
   
   plotcontrolpars <- c('ylab','xlab')
@@ -153,37 +152,50 @@ polygon=TRUE, polygonalpha=.1,polygoncontrol=list(border=NA)){
   if(all(lwdvec=='auto')) lwdvec = rep(3,nvars)
   if(all(colvec=='auto')) colvec = rainbow(nvars)
   if(all(typevec=='auto')) typevec = rep('l',nvars)
-  if(all(mainvec=='auto')){
-    if(separate) mainvec=dimnames(yarray)[[2]] else mainvec =rep(ifelse(is.null(plotcontrol$main),'',plotcontrol$main),nvars)
-  }
+  # if(all(mainvec=='auto')){
+  #   if(separate) mainvec=dimnames(yarray)[[2]] else mainvec =rep(ifelse(is.null(plotcontrol$main),'',plotcontrol$main),nvars)
+  # }
 
   plotargs<-plotcontrol
   plotargs$x <- x
   if(!separate && is.null(plotcontrol$ylim)) plotargs$ylim = range(yarray)
-   plotargs$xlim = range(x)
+   plotargs$xlim = range(x,na.rm=TRUE)
    
    ctpolyargs<-polygoncontrol
    
    legargs<-legendcontrol
   
-for(pari in 1:dim(yarray)[2]){
-  
-  plotargs$y = yarray[,pari,2]
+   
+   #blank plot
+   blankargs=plotargs
+   blankargs$y=NA
+   blankargs$x=NA
+   do.call(plot,blankargs)
+   if(grid) grid()
+   
+   #confidence
+   if(polygon) {
+     for(pari in c(1:dim(yarray)[2],dim(yarray)[2]:1)){
+     ctpolyargs$col=adjustcolor(colvec[pari],alpha.f=max(c(.004,polygonalpha/ctpolyargs$steps)))
+     ctpolyargs$x=plotargs$x
+     ctpolyargs$y=yarray[,pari,2]
+     ctpolyargs$yhigh = yarray[,pari,3]
+     ctpolyargs$ylow = yarray[,pari,1]
+     
+     do.call(ctPoly,ctpolyargs) 
+     }
+   }
+   
+for(pari in c(1:dim(yarray)[2],dim(yarray)[2]:1)){
+  for(qi in 1:3){
+  plotargs$y = yarray[,pari,qi]
   plotargs$col=colvec[pari]
-  plotargs$lwd=lwdvec[pari]
+  plotargs$lwd=ifelse(qi==2,lwdvec[pari],1)
   plotargs$lty=ltyvec[pari]
+  if(qi!=2) plotargs$col =grDevices::adjustcolor(plotargs$col,alpha.f=.5)
   plotargs$type=typevec[pari]
-  plotargs$main=mainvec[pari]
-  
-  if(pari==1 || separate) do.call(plot,plotargs)  else do.call(points,plotargs)
-  if(grid) grid()
-  if(polygon) {
-    ctpolyargs$col=adjustcolor(plotargs$col,alpha.f=polygonalpha)
-    ctpolyargs$x=plotargs$x
-    ctpolyargs$yhigh = yarray[,pari,3]
-    ctpolyargs$ylow = yarray[,pari,1]
-    
-    do.call(ctPoly,ctpolyargs) 
+  # plotargs$main=mainvec[pari]
+  do.call(points,plotargs)
   }
   
   if(separate & legend) {
